==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/sr.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Веза:",
    "Password:" : "Лозинка:",
    "Generating system report failed." : "Генерисање системског извештаја није успело.",
    "Nextcloud Subscription" : "Некстклауд претплата",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Ваш сервер нема Некстклауд Претплату или је Претплата истекла.",
    "Thank you," : "Хвала Вам,",
    "Your Nextcloud team" : "Ваш Некстклауд тим",
    "Support" : "Подршка",
    "Subscription" : "Претплата",
    "Valid subscription" : "Исправна претплата",
    "Expired subscription" : "Истекла претплата",
    "Subscription key:" : "Кључ претплате:",
    "_Expires in %n year_::_Expires in %n years_" : ["Истиче за %n годину","Истиче за %n године","Истиче за %n година"],
    "Get a quote" : "Добијте понуду",
    "More information" : "Још информација",
    "Subscription benefits" : "Предности претплате",
    "Pricing" : "Цене",
    "Commmunity support" : "Подршка заједнице",
    "Forum" : "Форум",
    "Nextcloud forum" : "Некстклауд форум",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud користи GitHub као платформу за заједнички рад. Можете директно тамо пријавити грешке.",
    "Nextcloud at GitHub" : "Nextcloud на GitHub-у",
    "Chat" : "Ћаскање",
    "Open chat" : "Отвори ћаскање",
    "Subscription key" : "Кључ претплате",
    "Set subscription key" : "Постави кључ претплате",
    "News" : "Вести",
    "Follow us on Google+" : "Пратите нас на Google+-у",
    "Like our Facebook page" : "Лајкујте нам Фејсбук страну",
    "Follow us on Twitter" : "Запратите нас на Твитеру",
    "Check out our blog" : "Баците поглед на наш блог",
    "Subscribe to our newsletter" : "Претплатите се на билтен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/sr.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Веза:",
    "Password:" : "Лозинка:",
    "Generating system report failed." : "Генерисање системског извештаја није успело.",
    "Subscription notifications" : "Обавештења о претплати",
    "Could not create folder \"System information\" to store generated report." : "Не могу да креирам фасциклу „System information“ за складиштење генерисаних извештаја.",
    "Could not create file \"%s\" to store generated report." : "Не могу да креирам фасциклу „%s“ за складиштење генерисаних извештаја.",
    "Could not share file \"%s\"." : "Не могу да поделим фајл „%s“.",
    "Nextcloud Subscription" : "Некстклауд претплата",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Ваш сервер нема Некстклауд Претплату или је Претплата истекла.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ваша Некстклауд претплата не покрива Ваш број корисника.",
    "Thank you," : "Хвала Вам,",
    "Your Nextcloud team" : "Ваш Некстклауд тим",
    "Support" : "Подршка",
    "Subscription" : "Претплата",
    "Valid subscription" : "Исправна претплата",
    "Expired subscription" : "Истекла претплата",
    "Subscription key:" : "Кључ претплате:",
    "_Expires in %n year_::_Expires in %n years_" : ["Истиче за %n годину","Истиче за %n године","Истиче за %n година"],
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Сакупља информације о систему за потребе подршку. Дугме испод генерише текстуални фајл у фасцикли „System information“ и дели је као јавну везу заштићену лозинком. Веза важи 2 недеље.",
    "Get a quote" : "Добијте понуду",
    "More information" : "Још информација",
    "Subscription benefits" : "Предности претплате",
    "Pricing" : "Цене",
    "Commmunity support" : "Подршка заједнице",
    "Forum" : "Форум",
    "Nextcloud forum" : "Некстклауд форум",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud користи GitHub као платформу за заједнички рад. Можете директно тамо пријавити грешке.",
    "Nextcloud at GitHub" : "Nextcloud на GitHub-у",
    "Chat" : "Ћаскање",
    "Open chat" : "Отвори ћаскање",
    "Subscription key" : "Кључ претплате",
    "Set subscription key" : "Постави кључ претплате",
    "News" : "Вести",
    "Follow us on Google+" : "Пратите нас на Google+-у",
    "Like our Facebook page" : "Лајкујте нам Фејсбук страну",
    "Follow us on Twitter" : "Запратите нас на Твитеру",
    "Check out our blog" : "Баците поглед на наш блог",
    "Subscribe to our newsletter" : "Претплатите се на билтен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
